lck.django.choices
==================

.. automodule:: lck.django.choices

Classes
-------

.. autoclass:: Choices
   :members:
   :member-order: bysource
   :content: both

.. autoclass:: Choice
   :members:
   :inherited-members:

.. autoclass:: ChoiceGroup
   :members:
   :inherited-members:

Predefined Choices
------------------

.. autoclass:: Country
   :members:
   :member-order: bysource
   :undoc-members:

.. autoclass:: Gender
   :members:
   :member-order: bysource
   :undoc-members:

.. autoclass:: Language
   :members:
   :member-order: bysource
   :undoc-members:
